@@ -608,41 +608,3 @@ pub trait WifiAsync {
     async fn get_configuration(&self) -> Result<Configuration, Self::Error>;
     async fn set_configuration(&mut self, conf: &Configuration) -> Result<(), Self::Error>;
 }
-
-#[cfg(feature = "alloc")]
-pub struct AnyhowWifi<T>(pub T);
-
-#[cfg(feature = "alloc")]
-impl<E, W> Wifi for AnyhowWifi<W>
-where
-    E: Into<anyhow::Error>,
-    W: Wifi<Error = E>,
-{
-    type Error = anyhow::Error;
-
-    fn get_capabilities(&self) -> Result<EnumSet<Capability>, Self::Error> {
-        self.0.get_capabilities().map_err(Into::into)
-    }
-
-    fn get_status(&self) -> Status {
-        self.0.get_status()
-    }
-
-    //fn scan_n<const N: usize = 20>(&mut self) -> Result<([AccessPointInfo; N], usize)>;
-    fn scan_fill(&mut self, access_points: &mut [AccessPointInfo]) -> Result<usize, Self::Error> {
-        self.0.scan_fill(access_points).map_err(Into::into)
-    }
-
-    #[cfg(feature = "alloc")]
-    fn scan(&mut self) -> Result<alloc::vec::Vec<AccessPointInfo>, Self::Error> {
-        self.0.scan().map_err(Into::into)
-    }
-
-    fn get_configuration(&self) -> Result<Configuration, Self::Error> {
-        self.0.get_configuration().map_err(Into::into)
-    }
-
-    fn set_configuration(&mut self, conf: &Configuration) -> Result<(), Self::Error> {
-        self.0.set_configuration(conf).map_err(Into::into)
-    }
-}
